@@ -20,7 +20,7 @@
 //! | anyhow | Easier error handling |
 //! | fastrand | Easy Random number generation |
 //! | glob | File globbing and matching |
-//! | lazy_static | Safe globals |
+//! | once_cell | Safe global vars |
 //! | rayon | Easy concurrency |
 //! | regex | Regular Expressions |
 //! | structopt | CLI arg parsing |
@@ -28,7 +28,7 @@
 pub use anyhow;
 pub use fastrand;
 pub use glob;
-pub use lazy_static;
+pub use once_cell;
 pub use rayon;
 pub use regex;
 pub use structopt;
